@@ -13,7 +13,7 @@ from time import time, sleep
 from warnings import warn
 import h5py
 
-from ..core.io.hdf_utils import assign_group_index, write_simple_attrs, attempt_reg_ref_build, write_region_references
+from pyUSID.io.hdf_utils import assign_group_index, write_simple_attrs, attempt_reg_ref_build, write_region_references
 from .virtual_data import VirtualGroup, VirtualDataset, VirtualData
 from ..__version__ import version
 
