@@ -21,7 +21,7 @@ from pyUSID.io.hdf_utils import write_ind_val_dsets, write_main_dataset, write_r
     create_indexed_group, write_simple_attrs, write_book_keeping_attrs, copy_attributes,\
     write_reduced_spec_dsets
 from pyUSID.io.usi_data import USIDataset
-from pyUSID.io.io_utils import get_available_memory
+from pyUSID.processing.comp_utils import get_available_memory
 
 class BEodfTranslator(Translator):
     """
