@@ -18,7 +18,7 @@ import xlrd as xlreader
 from pyUSID.io.hdf_utils import get_auxiliary_datasets, find_dataset, get_h5_obj_refs, link_h5_objects_as_attrs, \
     get_attr, create_indexed_group, write_simple_attrs, write_main_dataset, Dimension
 from pyUSID.io.write_utils import create_spec_inds_from_vals
-from pyUSID.io.io_utils import get_available_memory, recommend_cpu_cores
+from pyUSID.processing.comp_utils import get_available_memory, recommend_cpu_cores
 from ....analysis.optimize import Optimize
 from ....processing.histogram import build_histogram
 from ....viz.be_viz_utils import plot_1d_spectrum, plot_2d_spectrogram, plot_histograms
