@@ -18,9 +18,9 @@ from skimage.util import crop
 
 from .df_utils.image_utils import unnest_parm_dicts
 from .df_utils.dm_utils import read_dm3
-from ...core.io.translator import Translator, generate_dummy_main_parms
-from ...core.io.write_utils import Dimension, calc_chunks
-from ...core.io.hdf_utils import write_main_dataset, create_indexed_group, write_simple_attrs
+from pyUSID.io.translator import Translator, generate_dummy_main_parms
+from pyUSID.io.write_utils import Dimension, calc_chunks
+from pyUSID.io.hdf_utils import write_main_dataset, create_indexed_group, write_simple_attrs
 
 
 class NDataTranslator(Translator):
@@ -291,7 +291,7 @@ class NDataTranslator(Translator):
             h5_ronch = this_channel.create_dataset('Mean_Ronchigram',
                                                    data=np.zeros(num_pixels, dtype=np.float32))
 
-            h5_mean_spec = this_channel.create_dataset('Mean_Ronchigram',
+            h5_mean_spec = this_channel.create_dataset('Mean_Spectrogram',
                                                        data=np.zeros(num_images, dtype=np.float32))
 
             this_data = self.binning_func(this_data, self.bin_factor, self.bin_func).reshape(h5_main.shape)
