@@ -19,7 +19,7 @@ from .df_utils.dm_utils import parse_dm4_parms, read_dm3
 from pyUSID.io.translator import Translator, generate_dummy_main_parms
 from pyUSID.io.write_utils import Dimension, calc_chunks
 from pyUSID.io.hdf_utils import create_indexed_group, write_main_dataset, write_simple_attrs
-from pyUSID.io.image import read_image
+from pycroscopy.io.translators.image import read_image
 
 
 class OneViewTranslator(Translator):
@@ -184,10 +184,10 @@ class OneViewTranslator(Translator):
         Set the Measurement Group attributes
         '''
         usize, vsize = image.shape
-        image_parms.attrs['image_size_u'] = usize
-        image_parms.attrs['image_size_v'] = vsize
-        image_parms.attrs['translator'] = 'OneView'
-        image_parms.attrs['num_pixels'] = image.size
+        image_parms['image_size_u'] = usize
+        image_parms['image_size_v'] = vsize
+        image_parms['translator'] = 'OneView'
+        image_parms['num_pixels'] = image.size
         write_simple_attrs(meas_grp, image_parms)
 
         '''
